@@ -23,6 +23,12 @@ game.c -- Routines to initialize, save, and restore a game.
 #include "extern.h"
 
 long remove_land(long loc, long num_land);
+int select_cities();
+int find_next(long *mapi);
+int good_cont(long mapi);
+int xread(FILE *f, char *buf, int size);
+int xwrite(FILE *f, char *buf, int size);
+void stat_display( char *mbuf, int round);
 
 /*
 Initialize a new game.  Here we generate a new random map, put cities
@@ -502,9 +508,9 @@ tell the user why.
 void save_game () {
 	FILE *f; /* file to save game in */
 
-	f = fopen ("empsave.dat", "w"); /* open for output */
+	f = fopen (savefile, "w"); /* open for output */
 	if (f == NULL) {
-		perror ("Cannot save empsave.dat");
+		perror ("Cannot save saved game");
 		return;
 	}
 	wbuf (map);
@@ -544,9 +550,9 @@ int restore_game () {
 	piece_info_t **list;
 	piece_info_t *obj;
 
-	f = fopen ("empsave.dat", "r"); /* open for input */
+	f = fopen (savefile, "r"); /* open for input */
 	if (f == NULL) {
-		perror ("Cannot open empsave.dat");
+		perror ("Cannot open saved game");
 		return (FALSE);
 	}
 	rbuf (map);
@@ -613,7 +619,7 @@ int restore_game () {
 	
 	(void) fclose (f);
 	kill_display (); /* what we had is no longer good */
-	topmsg (3, "Game restored from empsave.dat.",0,0,0,0,0,0,0,0);
+	topmsg (3, "Game restored from save file.",0,0,0,0,0,0,0,0);
 	return (TRUE);
 }
 	
@@ -649,7 +655,7 @@ int piece_type;
 }
 
 void inconsistent () {
-	(void) printf ("empsave.dat is inconsistent.  Please remove it.\n");
+	(void) printf ("saved game is inconsistent.  Please remove it.\n");
 	exit (1);
 }
 
@@ -794,7 +800,7 @@ The "xxxxx" field is the cumulative cost of building the hardware.
 /* in declared order, with city first */
 static char *pieces = "OAFPDSTCBZXafpdstcbz";
 
-stat_display (mbuf, round)
+void stat_display (mbuf, round)
 char *mbuf;
 int round;
 {
